"use strict";

var _tape = _interopRequireDefault(require("tape"));

var _reduxBundler = require("redux-bundler");

var _appTimeExtended = require("./app-time-extended");

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

(0, _tape.default)('selectAppTimeSecond, selectAppTimeMinute, selectAppTimeDay, selectAppDayDate', t => {
  const appTime = 1713219284435;
  const expectedStartingSecond = 1713219284000;
  const expectedStartingMinute = 1713219240000; // without this adjustment, the test would fail in CI

  const expectedStartingDay = 1713139200000 + new Date().getTimezoneOffset() * 60000;

  const getStoreForAppTime = appTime => (0, _reduxBundler.composeBundlesRaw)({
    name: 'appTimeStub',
    reducer: (state = appTime, {
      type,
      payload
    }) => type === 'APP_TIME' ? payload : state,
    selectAppTime: state => state.appTimeStub
  }, _appTimeExtended.appTimeExtendedBundle)();

  const store = getStoreForAppTime(appTime);
  t.equal(store.selectAppTime(), appTime);
  t.equal(store.selectAppTimeSecond(), expectedStartingSecond);
  t.equal(store.selectAppTimeMinute(), expectedStartingMinute);
  t.equal(store.selectAppTimeDay(), expectedStartingDay);
  const firstDateObject = store.selectAppDayDate();
  let secondsCallCount = 0;
  let minutesCallCount = 0;
  let dayCallCount = 0;
  store.subscribeToSelectors(['selectAppTimeSecond'], () => {
    secondsCallCount++;
  });
  store.subscribeToSelectors(['selectAppTimeMinute'], () => {
    minutesCallCount++;
  });
  store.subscribeToSelectors(['selectAppTimeDay', 'selectAppDayDate'], () => {
    dayCallCount++;
  });
  store.dispatch({
    type: 'APP_TIME',
    payload: store.selectAppTime() + 1000
  });
  t.equal(store.selectAppTime(), appTime + 1000);
  t.equal(store.selectAppTimeSecond(), expectedStartingSecond + 1000);
  t.equal(store.selectAppTimeMinute(), expectedStartingMinute);
  t.equal(store.selectAppTimeDay(), expectedStartingDay);
  t.equal(secondsCallCount, 1);
  t.equal(minutesCallCount, 0);
  t.equal(dayCallCount, 0);
  t.equal(store.selectAppDayDate(), firstDateObject, 'returns same actual object when day does not change');
  store.dispatch({
    type: 'APP_TIME',
    payload: store.selectAppTime() + 60000
  });
  t.equal(store.selectAppTime(), appTime + 1000 + 60000);
  t.equal(store.selectAppTimeSecond(), expectedStartingSecond + 1000 + 60000);
  t.equal(store.selectAppTimeMinute(), expectedStartingMinute + 60000);
  t.equal(store.selectAppTimeDay(), expectedStartingDay);
  t.equal(secondsCallCount, 2);
  t.equal(minutesCallCount, 1);
  t.equal(dayCallCount, 0);
  t.equal(store.selectAppDayDate(), firstDateObject, 'returns same actual object when day does not change');
  store.dispatch({
    type: 'APP_TIME',
    payload: store.selectAppTime() + 86400000
  });
  t.equal(store.selectAppTime(), appTime + 1000 + 60000 + 86400000);
  t.equal(store.selectAppTimeSecond(), expectedStartingSecond + 1000 + 60000 + 86400000);
  t.equal(store.selectAppTimeMinute(), expectedStartingMinute + 60000 + 86400000);
  t.equal(store.selectAppTimeDay(), expectedStartingDay + 86400000);
  t.deepEqual(store.selectAppDayDate(), new Date(expectedStartingDay + 86400000));
  t.notEqual(store.selectAppDayDate(), firstDateObject, 'returns different date object when date changes');
  t.equal(secondsCallCount, 3);
  t.equal(minutesCallCount, 2);
  t.equal(dayCallCount, 1);
  t.end();
});