"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.getTimeDiffBundle = void 0;

var _reduxBundler = require("redux-bundler");

var _date = require("../utils/date");

/**
 * @param {{
 *   timeDiffThreshold?: number
 *   actionName?: string
 *   getServerTimePromise?: Promise<number>
 * }} [opts]
 * @returns {any}
 */
const getTimeDiffBundle = ({
  timeDiffThreshold = 300000
  /* 5 minutes */
  ,
  actionName = 'SERVER_TIME_FETCHED',
  getServerTimePromise
} = {}) => ({
  name: 'timeDiff',
  reducer: (state = {
    timeDiff: null
  }, {
    type,
    payload
  }) => type === actionName ? {
    timeDiff: payload
  } : state,
  init: store => store.doFetchServerTime(),
  doFetchServerTime: () => ({
    dispatch,
    gqlFetch
  }) => (getServerTimePromise ? getServerTimePromise() : gqlFetch('{serverTime}').then(res => res.data.serverTime)).then(serverTime => dispatch({
    type: actionName,
    payload: Date.now() - serverTime
  })),
  selectServerTimeDiffRaw: state => state.timeDiff.timeDiff,
  selectClientTimeStatus: (0, _reduxBundler.createSelector)('selectServerTimeDiffRaw', timeDiff => {
    let ok = null;
    let message = null;

    if (timeDiff !== null) {
      ok = Math.abs(timeDiff) <= timeDiffThreshold;
    }

    if (ok === false) {
      message = "".concat((0, _date.msToTimeAgo)(Math.abs(timeDiff), false), " ").concat(timeDiff > 0 ? 'ahead' : 'behind');
    }

    return {
      timeDiff,
      ok,
      message
    };
  }),
  selectClientTimeOk: (0, _reduxBundler.createSelector)('selectClientTimeStatus', status => !!status.ok)
});

exports.getTimeDiffBundle = getTimeDiffBundle;