"use strict";

var _tape = _interopRequireDefault(require("tape"));

var _getTimeDiffBundle = require("./get-time-diff-bundle");

var _reduxBundler = require("redux-bundler");

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

(0, _tape.default)('getTimeDiffBundle reducer', async t => {
  const reducer = (0, _getTimeDiffBundle.getTimeDiffBundle)().reducer;
  t.deepEqual(reducer(undefined, {}), {
    timeDiff: null
  }, 'should return initial state');
  t.deepEqual(reducer(undefined, {
    type: 'SERVER_TIME_FETCHED',
    payload: 5000
  }), {
    timeDiff: 5000
  }, 'should update timeDiff when actionName is matched');
  t.deepEqual((0, _reduxBundler.composeBundlesRaw)((0, _getTimeDiffBundle.getTimeDiffBundle)({
    getServerTimePromise: () => Promise.resolve()
  }))().selectClientTimeStatus(), {
    timeDiff: null,
    ok: null,
    message: null
  }, 'should start out null and unknown');

  const getStoreWithServerTime = async serverTime => {
    const store = (0, _reduxBundler.composeBundlesRaw)((0, _getTimeDiffBundle.getTimeDiffBundle)({
      getServerTimePromise: () => Promise.resolve(serverTime)
    }))();
    await Promise.resolve();
    return store;
  };

  const getStatusWithServerTime = serverTime => getStoreWithServerTime(serverTime).then(store => store.selectClientTimeStatus());

  let res = await getStatusWithServerTime(Date.now());
  t.equal(res.ok, true, 'status ok if close');
  t.ok(res.timeDiff < 200, 'time diff is small');
  res = await getStatusWithServerTime(Date.now() - 400000);
  t.equal(res.ok, false, 'ok is false if ahead');
  res = await getStatusWithServerTime(Date.now() + 400000);
  t.equal(res.ok, false, 'ok is false if behind');

  const getMessageWithServerTime = async (serverTime) => getStatusWithServerTime(serverTime).then(res => res.message);

  const scenarios = [[-4000000, '1h 6m ahead'], [-400000, '6m ahead'], [400000, '6m behind'], [20000, null], [1000 * 60 * 5 + 100, '5m behind'], [-(1000 * 60 * 5) - 100, '5m ahead']];

  for (const [serverTime, expected] of scenarios) {
    t.equal(await getMessageWithServerTime(Date.now() + serverTime), expected, "message is correct for ".concat(serverTime));
  }

  t.equal(await getStoreWithServerTime(Date.now() + 2000).then(store => store.selectClientTimeOk()), true, 'selectClientTimeOk is true if close');
  t.equal(await getStoreWithServerTime(Date.now() + 500000).then(store => store.selectClientTimeOk()), false, 'selectClientTimeOk is false otherwise');
  t.end();
});