"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.getXIDBundle = void 0;

var _reduxBundler = require("redux-bundler");

var _milliseconds = _interopRequireDefault(require("milliseconds"));

var _cookie = require("../utils/cookie");

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

function ownKeys(object, enumerableOnly) { var keys = Object.keys(object); if (Object.getOwnPropertySymbols) { var symbols = Object.getOwnPropertySymbols(object); if (enumerableOnly) symbols = symbols.filter(function (sym) { return Object.getOwnPropertyDescriptor(object, sym).enumerable; }); keys.push.apply(keys, symbols); } return keys; }

function _objectSpread(target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i] != null ? arguments[i] : {}; if (i % 2) { ownKeys(Object(source), true).forEach(function (key) { _defineProperty(target, key, source[key]); }); } else if (Object.getOwnPropertyDescriptors) { Object.defineProperties(target, Object.getOwnPropertyDescriptors(source)); } else { ownKeys(Object(source)).forEach(function (key) { Object.defineProperty(target, key, Object.getOwnPropertyDescriptor(source, key)); }); } } return target; }

function _defineProperty(obj, key, value) { if (key in obj) { Object.defineProperty(obj, key, { value: value, enumerable: true, configurable: true, writable: true }); } else { obj[key] = value; } return obj; }

const UPDATED = 'XID_UPDATED';

const createXIDWriter = ({
  name = 'xid',
  domain
}) => ({
  writeXID: value => {
    (0, _cookie.writeCookie)(name, value, {
      maxAge: _milliseconds.default.days(180),
      secure: true,
      domain
    });
  },
  readXID: () => (0, _cookie.readCookie)(name),
  clearXID: () => (0, _cookie.deleteCookie)(name, domain)
});
/**
 * @param {{
 *   xidName: string
 *   domain: string
 *   writerStub?: {
 *     readXID: () => string
 *     writeXID: (value: string) => void
 *     clearXID: () => void
 *   }
 *   readInterval?: number
 * }} opts
 * @returns
 */


const getXIDBundle = opts => {
  const {
    xidName,
    domain,
    readInterval,
    writerStub
  } = opts;
  const readInt = readInterval || 3000;
  const {
    readXID,
    writeXID,
    clearXID
  } = writerStub || createXIDWriter({
    name: xidName,
    domain
  });
  return {
    name: 'xid',
    reducer: (state = {
      xid: readXID()
    }, {
      type,
      payload
    }) => {
      if (type === UPDATED) {
        return _objectSpread(_objectSpread({}, state), {}, {
          xid: payload
        });
      }

      return state;
    },
    init: store => {
      if (_reduxBundler.IS_BROWSER) {
        const read = () => {
          store.doSyncXID();
          setTimeout(() => (0, _reduxBundler.ric)(read), readInt);
        };

        setTimeout(read, readInt);
      }
    },
    selectXID: state => state.xid.xid,
    doWriteXID: value => ({
      store
    }) => {
      // should not happen, but as a guard
      if (!value) return;
      const currentValue = store.selectXID();

      if (currentValue && currentValue !== value) {
        // we have a value already, and it's different, so clear it
        // and refresh the page
        store.doClearXID();
      } else {
        writeXID(value);
      }

      store.doSyncXID();
    },
    doClearXID: () => () => clearXID(),
    // reads the current cookie value into the store's cache if the store doesn't have one yet
    // signs us out on this tab if the cookie value has changed
    doSyncXID: () => ({
      store
    }) => {
      const cachedValue = store.selectXID();
      const value = readXID(); // if we had one, but now it's suddenly different or gone
      // we have to sign out

      if (cachedValue && value !== cachedValue) {
        window.location.assign('/');
        return;
      }

      if (!cachedValue && value) {
        store.dispatch({
          type: UPDATED,
          payload: value
        });
      }
    }
  };
};

exports.getXIDBundle = getXIDBundle;