"use strict";

var _tape = _interopRequireDefault(require("tape"));

var _getXidBundle = require("./get-xid-bundle");

var _reduxBundler = require("redux-bundler");

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

/* eslint-disable no-undef */
const getStore = xidBundleOpts => (0, _reduxBundler.composeBundlesRaw)((0, _getXidBundle.getXIDBundle)(xidBundleOpts))({});

(0, _tape.default)('getXIDBundle', async t => {
  let current = null;
  const writerStub = {
    readXID: () => current,
    writeXID: val => {
      current = val;
    },
    clearXID: () => {
      current = null;
    }
  };
  const store = getStore({
    xidName: 'xid',
    domain: 'xchart.com',
    writerStub
  });
  t.equal(store.selectXID(), null, 'should be null to start');
  current = '123';
  store.doSyncXID();
  t.equal(store.selectXID(), '123', 'should be 123'); // should not write if value is null

  store.doWriteXID(null);
  t.equal(store.selectXID(), '123', 'should still be 123'); // should write but because it is different
  // this should cause an attempt to refresh the page

  try {
    store.doWriteXID('456');
    t.fail("shouldn't get here");
  } catch (err) {
    // stand-in in for window.location.assign('/')
    t.equal(err.message, 'window is not defined');
  } // calling this only clears the cookie it does not clear the cache
  // this is intentional. It's not until you call doSyncXID that the
  // change is detected and the page is refreshed.
  // This is so that the session bundle can clear the cookie but have
  // a chance to do something else before refreshing the page.


  store.doClearXID();
  t.equal(store.selectXID(), '123', 'it has not cleared the value from the cache');
  t.equal(current, null, 'it has cleared the cookie');

  try {
    // it's here if we now call doSyncXID where suddenly since it's gone
    // we should refresh the page.
    store.doSyncXID();
    t.fail("shouldn't get here");
  } catch (err) {
    // stand-in in for window.location.assign('/')
    t.equal(err.message, 'window is not defined');
  }

  t.end();
});