"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.CurrentVitalsStatusSection = void 0;

var _preact = require("preact");

var _section = _interopRequireDefault(require("./section"));

var _currentVitalsStatus = require("../current-vitals-status");

var _acFile = require("ac-file");

var _milliseconds = _interopRequireDefault(require("milliseconds"));

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

function ownKeys(object, enumerableOnly) { var keys = Object.keys(object); if (Object.getOwnPropertySymbols) { var symbols = Object.getOwnPropertySymbols(object); if (enumerableOnly) symbols = symbols.filter(function (sym) { return Object.getOwnPropertyDescriptor(object, sym).enumerable; }); keys.push.apply(keys, symbols); } return keys; }

function _objectSpread(target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i] != null ? arguments[i] : {}; if (i % 2) { ownKeys(Object(source), true).forEach(function (key) { _defineProperty(target, key, source[key]); }); } else if (Object.getOwnPropertyDescriptors) { Object.defineProperties(target, Object.getOwnPropertyDescriptors(source)); } else { ownKeys(Object(source)).forEach(function (key) { Object.defineProperty(target, key, Object.getOwnPropertyDescriptor(source, key)); }); } } return target; }

function _defineProperty(obj, key, value) { if (key in obj) { Object.defineProperty(obj, key, { value: value, enumerable: true, configurable: true, writable: true }); } else { obj[key] = value; } return obj; }

const generateRandomVitalValue = vital => {
  if (vital.id === 'bp') {
    const sbp = 120 + Math.floor(Math.random() * 40 - 20);
    const dbp = 80 + Math.floor(Math.random() * 40 - 20);
    return {
      sbp,
      dbp,
      map: Math.round((sbp + 2 * dbp) / 3)
    };
  }

  if (vital.type !== 'number') {
    return null;
  } // @ts-ignore


  let {
    startValue,
    min,
    max
  } = vital;
  if (!startValue) startValue = 10;
  const adjustBy = Math.floor(Math.random() * 20 - 5);

  if (min != null) {
    return startValue + adjustBy > min ? startValue + adjustBy : startValue - adjustBy;
  }

  if (max != null) {
    return startValue + adjustBy < max ? startValue + adjustBy : startValue - adjustBy;
  }

  return startValue + adjustBy;
};

const StatusBarWrapper = ({
  className = '',
  children
}) => (0, _preact.h)("div", {
  className: "ba pa2 b--light-gray ".concat(className)
}, children);

class CurrentVitalsStatusSection extends _preact.Component {
  constructor(props) {
    super(props);
    const vitalValuesLists = {};

    for (const vital of (0, _acFile.getUserSelectableVitalTypes)({
      tempUnit: 'F'
    })) {
      vitalValuesLists[vital.id] = [];

      for (let i = 0; i < 20; i++) {
        vitalValuesLists[vital.id].push(generateRandomVitalValue(vital));
      }
    }

    this.state = {
      start: Date.now(),
      now: Date.now(),
      vitalValuesLists
    };
  }

  componentDidMount() {
    this.refreshTimer = setInterval(() => this.setState({
      now: Date.now()
    }), 1000);
  }

  componentWillUnmount() {
    clearInterval(this.refreshTimer);
  }

  getVitals(vitalsToRefreshRate) {
    /** @type {import('../current-vitals-status.types').ReportedVitalMap} */
    const vitals = {};
    let time = 0;

    for (const [id, refreshRate] of Object.entries(vitalsToRefreshRate)) {
      if (refreshRate === -1) {
        vitals[id] = {
          value: null,
          time: null
        };
        continue;
      }

      const i = Math.floor((this.state.now - this.state.start) / refreshRate);
      const vitalTime = this.state.start + i * refreshRate;

      if (vitalTime > time) {
        time = vitalTime;
      }

      vitals[id] = {
        value: this.state.vitalValuesLists[id][i % 20],
        time: vitalTime
      };
    }

    return {
      lastUpdated: time,
      vitals
    };
  }

  render(_, {
    now
  }) {
    const currentVitals = {
      orgId: 'test-org',
      compositionId: '1234',
      monitorType: 'test-monitor',
      monitorLabel: 'Test Monitor',
      autoVitalsStatus: 'connected',
      lastUpdated: now,
      simulated: false,
      vitals: {}
    };
    return (0, _preact.h)(_section.default, {
      title: "Current Vitals Status"
    }, (0, _preact.h)("h4", null, "Waiting"), (0, _preact.h)(StatusBarWrapper, null, (0, _preact.h)(_currentVitalsStatus.CurrentVitalsStatus, {
      currentVitals: _objectSpread(_objectSpread({}, currentVitals), {}, {
        autoVitalsStatus: 'waiting'
      }),
      isLocal: false
    })), (0, _preact.h)("h4", null, "No vitals yet"), (0, _preact.h)(StatusBarWrapper, null, (0, _preact.h)(_currentVitalsStatus.CurrentVitalsStatus, {
      currentVitals: _objectSpread(_objectSpread({}, currentVitals), {}, {
        vitals: null
      }),
      isLocal: false
    })), (0, _preact.h)("h4", null, "Normal use"), (0, _preact.h)(StatusBarWrapper, null, (0, _preact.h)(_currentVitalsStatus.CurrentVitalsStatus, {
      currentVitals: _objectSpread(_objectSpread({}, currentVitals), this.getVitals({
        bp: 20000,
        hr: 5000,
        etco2: 6000,
        spo2: 7000
      })),
      isLocal: false
    })), (0, _preact.h)("h4", null, "Normal use inverted"), (0, _preact.h)(StatusBarWrapper, {
      className: "bg-light-blue"
    }, (0, _preact.h)(_currentVitalsStatus.CurrentVitalsStatus, {
      currentVitals: _objectSpread(_objectSpread({}, currentVitals), this.getVitals({
        bp: 20000,
        hr: 5000,
        etco2: 6000,
        spo2: 7000
      })),
      isLocal: true
    })), (0, _preact.h)("h4", null, "Missing Vital"), (0, _preact.h)(StatusBarWrapper, null, (0, _preact.h)(_currentVitalsStatus.CurrentVitalsStatus, {
      currentVitals: _objectSpread(_objectSpread({}, currentVitals), this.getVitals({
        hr: 2000,
        etco2: -1,
        spo2: 4000
      })),
      isLocal: false
    })), (0, _preact.h)("h4", null, "Missing BP"), (0, _preact.h)(StatusBarWrapper, null, (0, _preact.h)(_currentVitalsStatus.CurrentVitalsStatus, {
      currentVitals: _objectSpread(_objectSpread({}, currentVitals), this.getVitals({
        sbp: -1,
        dbp: -1,
        hr: 2000
      })),
      isLocal: false
    })), (0, _preact.h)("h4", null, "Measuring BP"), (0, _preact.h)(StatusBarWrapper, null, (0, _preact.h)(_currentVitalsStatus.CurrentVitalsStatus, {
      currentVitals: _objectSpread(_objectSpread({}, currentVitals), {}, {
        vitals: {
          bp: {
            time: now,
            value: {
              sbp: 120,
              dbp: 80,
              map: 93
            },
            status: 'measuring'
          },
          hr: {
            time: now,
            value: 80
          }
        }
      }),
      isLocal: false
    })), (0, _preact.h)("h4", null, "BP error"), (0, _preact.h)(StatusBarWrapper, null, (0, _preact.h)(_currentVitalsStatus.CurrentVitalsStatus, {
      currentVitals: _objectSpread(_objectSpread({}, currentVitals), {}, {
        vitals: {
          bp: {
            time: now,
            value: {
              sbp: 120,
              dbp: 80,
              map: 93
            },
            error: 'uh oh'
          },
          hr: {
            time: now,
            value: 80
          }
        }
      }),
      isLocal: false
    })), (0, _preact.h)("h4", null, "Removes expired"), (0, _preact.h)(StatusBarWrapper, null, (0, _preact.h)(_currentVitalsStatus.CurrentVitalsStatus, {
      currentVitals: _objectSpread(_objectSpread({}, currentVitals), {}, {
        vitals: {
          bp: {
            time: now - _milliseconds.default.minutes(1),
            value: {
              sbp: 120,
              dbp: 80,
              map: 93
            }
          },
          // should both be shown
          hr: {
            time: now - _milliseconds.default.seconds(20),
            value: 80
          },
          rr: {
            time: now - _milliseconds.default.seconds(22),
            value: 50
          },
          // should not have value as too old
          etco2: {
            time: now - _milliseconds.default.seconds(27),
            value: 2
          }
        }
      }),
      isLocal: false,
      maxVitalAge: _milliseconds.default.seconds(30),
      maxBpAge: _milliseconds.default.minutes(2)
    })), (0, _preact.h)("h4", null, "Removes expired BP"), (0, _preact.h)(StatusBarWrapper, null, (0, _preact.h)(_currentVitalsStatus.CurrentVitalsStatus, {
      currentVitals: _objectSpread(_objectSpread({}, currentVitals), {}, {
        vitals: {
          bp: {
            time: now - _milliseconds.default.minutes(10),
            value: {
              sbp: 120,
              dbp: 80,
              map: 93
            }
          },
          hr: {
            time: now - _milliseconds.default.seconds(1),
            value: 80
          }
        }
      }),
      isLocal: false,
      maxBpAge: _milliseconds.default.minutes(2)
    })));
  }

}

exports.CurrentVitalsStatusSection = CurrentVitalsStatusSection;