"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.MoreMenu = exports.MoreMenuSeparator = exports.MoreMenuItemCopy = exports.MoreMenuItem = void 0;

var _preact = require("preact");

var _classnames = _interopRequireDefault(require("classnames"));

var _icon = require("./icon");

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

function _extends() { _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; }; return _extends.apply(this, arguments); }

function _objectWithoutProperties(source, excluded) { if (source == null) return {}; var target = _objectWithoutPropertiesLoose(source, excluded); var key, i; if (Object.getOwnPropertySymbols) { var sourceSymbolKeys = Object.getOwnPropertySymbols(source); for (i = 0; i < sourceSymbolKeys.length; i++) { key = sourceSymbolKeys[i]; if (excluded.indexOf(key) >= 0) continue; if (!Object.prototype.propertyIsEnumerable.call(source, key)) continue; target[key] = source[key]; } } return target; }

function _objectWithoutPropertiesLoose(source, excluded) { if (source == null) return {}; var target = {}; var sourceKeys = Object.keys(source); var key, i; for (i = 0; i < sourceKeys.length; i++) { key = sourceKeys[i]; if (excluded.indexOf(key) >= 0) continue; target[key] = source[key]; } return target; }

const MoreMenuItem = (_ref) => {
  let {
    onClick,
    className,
    hoverBg = 'lightest-blue',
    color = 'dark-gray'
  } = _ref,
      rest = _objectWithoutProperties(_ref, ["onClick", "className", "hoverBg", "color"]);

  return (0, _preact.h)("button", _extends({
    onClick: onClick,
    className: (0, _classnames.default)('button-reset bg-transparent no-shadow bn pointer pa2 f5 fw4 flex items-center db tl w-100', "hover-bg-".concat(hoverBg), color, className),
    style: {
      minWidth: '100px'
    }
  }, rest));
};

exports.MoreMenuItem = MoreMenuItem;

class MoreMenuItemCopy extends _preact.Component {
  constructor(props) {
    var _window$navigator, _window$navigator$cli;

    super(props);
    this.state = {
      copied: false,
      error: false
    };
    this.supported = !!((_window$navigator = window.navigator) !== null && _window$navigator !== void 0 && (_window$navigator$cli = _window$navigator.clipboard) !== null && _window$navigator$cli !== void 0 && _window$navigator$cli.writeText);

    this.failed = () => this.setState({
      error: true
    });

    this.handleClick = e => {
      e.stopImmediatePropagation();
      e.preventDefault();

      if (this.supported) {
        window.navigator.clipboard.writeText(this.props.text).then(() => {
          this.setState({
            copied: true
          });
          setTimeout(() => {
            this.setState({
              copied: false
            });
          }, 2000);
        }).catch(this.failed);
      } else {
        this.failed();
      }
    };
  }

  render() {
    const _this$props = this.props,
          {
      children
    } = _this$props,
          rest = _objectWithoutProperties(_this$props, ["children"]);

    const {
      copied,
      error
    } = this.state;
    return (0, _preact.h)(MoreMenuItem, _extends({
      onClick: this.handleClick
    }, rest), (0, _preact.h)("div", null, children, copied && (0, _preact.h)("span", {
      className: "ml2 gray"
    }, "(copied!)"), error && (0, _preact.h)("span", {
      className: "ml2 red"
    }, "(failed!)")));
  }

}

exports.MoreMenuItemCopy = MoreMenuItemCopy;

const MoreMenuSeparator = () => (0, _preact.h)("div", {
  className: "bb b--light-gray"
});

exports.MoreMenuSeparator = MoreMenuSeparator;

const px = val => "".concat(Math.round(val), "px");

class MoreMenu extends _preact.Component {
  constructor(props) {
    super(props);

    this.setToggleRef = dom => this.toggleRef = dom;

    this.open = () => this.setState({
      opened: true
    });

    this.close = () => this.setState({
      opened: false
    });

    this.closeOnOuterClick = e => {
      // Close on document click only if we aren't clicking on our own element
      // This ensures that we don't close when clicking on the toggle button
      // (which is already handled directly) but we _do_ close when clicking
      // on a different MoreMenu element
      if (this.toggleRef && !this.toggleRef.contains(e.target)) {
        this.close();
      }
    };

    this.toggle = () => {
      this.setState(({
        opened
      }) => ({
        opened: !opened
      }));
    };

    this.state = {
      opened: false
    };
    document.addEventListener('click', this.closeOnOuterClick);
  }

  componentWillUnmount() {
    document.removeEventListener('click', this.closeOnOuterClick);
  }

  render() {
    const {
      opened
    } = this.state;

    const _this$props2 = this.props,
          {
      size = 32,
      items = ['thing1', 'thing 2'],
      color = 'dark-gray',
      maxWidth = 350,
      minWidth = 100
    } = _this$props2,
          rest = _objectWithoutProperties(_this$props2, ["size", "items", "color", "maxWidth", "minWidth"]);

    const inPx = px(size);
    return (0, _preact.h)("div", rest, (0, _preact.h)("div", {
      className: "relative",
      style: {
        width: inPx,
        height: inPx
      }
    }, (0, _preact.h)("button", {
      ref: this.setToggleRef,
      className: (0, _classnames.default)('button-reset bg-transparent no-shadow bn pointer absolute flex items-center justify-center br-pill hover-bg-lightest-blue br-100', opened && 'bg-lightest-blue'),
      href: "#",
      onClick: this.toggle,
      style: {
        left: 0,
        width: inPx,
        height: inPx
      }
    }, (0, _preact.h)(_icon.Icon, {
      icon: "more_vert",
      className: color,
      size: Math.round(size * 0.75)
    })), (0, _preact.h)("div", {
      className: "absolute z-1",
      style: {
        maxWidth: px(maxWidth),
        minWidth: px(minWidth),
        right: 0,
        top: inPx
      }
    }, this.state.opened && (0, _preact.h)("div", {
      className: "bg-white shadow-1 br2 ba b--light-gray"
    }, items))));
  }

}

exports.MoreMenu = MoreMenu;