"use strict";

var _tape = _interopRequireDefault(require("tape"));

var _milliseconds = _interopRequireDefault(require("milliseconds"));

var _date = require("./date");

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

function ownKeys(object, enumerableOnly) { var keys = Object.keys(object); if (Object.getOwnPropertySymbols) { var symbols = Object.getOwnPropertySymbols(object); if (enumerableOnly) symbols = symbols.filter(function (sym) { return Object.getOwnPropertyDescriptor(object, sym).enumerable; }); keys.push.apply(keys, symbols); } return keys; }

function _objectSpread(target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i] != null ? arguments[i] : {}; if (i % 2) { ownKeys(Object(source), true).forEach(function (key) { _defineProperty(target, key, source[key]); }); } else if (Object.getOwnPropertyDescriptors) { Object.defineProperties(target, Object.getOwnPropertyDescriptors(source)); } else { ownKeys(Object(source)).forEach(function (key) { Object.defineProperty(target, key, Object.getOwnPropertyDescriptor(source, key)); }); } } return target; }

function _defineProperty(obj, key, value) { if (key in obj) { Object.defineProperty(obj, key, { value: value, enumerable: true, configurable: true, writable: true }); } else { obj[key] = value; } return obj; }

(0, _tape.default)('formatDate', t => {
  const dateToCompare = new Date(2021, 5, 3, 5);
  const opts = {
    now: dateToCompare
  };
  t.equal((0, _date.toFriendlyDate)(dateToCompare, opts), 'Today');
  t.equal((0, _date.toFriendlyDate)(dateToCompare.valueOf() + _milliseconds.default.days(1), opts), 'Tomorrow');
  t.equal((0, _date.toFriendlyDate)(dateToCompare.valueOf() - _milliseconds.default.days(1), opts), 'Yesterday');
  t.equal((0, _date.toFriendlyDate)(dateToCompare.valueOf() - _milliseconds.default.days(7), opts), 'May 27');
  t.equal((0, _date.toFriendlyDate)(dateToCompare.valueOf() - _milliseconds.default.days(6), opts), 'Last Friday');
  t.equal((0, _date.toFriendlyDate)(dateToCompare.valueOf() - _milliseconds.default.days(3), opts), 'Last Monday');
  t.equal((0, _date.toFriendlyDate)(dateToCompare.valueOf() + _milliseconds.default.days(6), opts), 'Wednesday');
  t.equal((0, _date.toFriendlyDate)(dateToCompare.valueOf() + _milliseconds.default.days(7), opts), 'June 10');
  t.equal((0, _date.toFriendlyDate)(dateToCompare.valueOf() + _milliseconds.default.days(2), _objectSpread(_objectSpread({}, opts), {}, {
    includeTime: true
  })), 'Saturday @ 05:00');
  t.equal((0, _date.toFriendlyDate)(new Date('Thu Jun 03 2021 00:00:00 GMT-0700'), {
    now: new Date(1622731348017)
  }), 'Today', 'Confirm test case from app, that was breaking'); // this is a bug in chrome, it returns 24:01 instead of 00:01
  // so we have some code to correct

  t.equal((0, _date.toFriendlyDate)(new Date(2020, 11, 14, 0, 1, 0), {
    includeTime: true
  }), 'December 14, 2020 @ 00:01');
  t.end();
});
(0, _tape.default)('toSimpleISODateString, fromSimpleISODateString', t => {
  let start = new Date(2022, 1, 8);
  let result = (0, _date.toSimpleISODateString)(start);
  t.equal(result, '2022-02-08', 'pads months/date');
  t.equal((0, _date.fromSimpleISODateString)(result).valueOf(), start.valueOf());
  start = new Date(2022, 1, 8, 23, 59, 59, 999);
  result = (0, _date.toSimpleISODateString)(start);
  t.equal(result, '2022-02-08', 'handles high');
  t.equal((0, _date.fromSimpleISODateString)(result).valueOf(), new Date(2022, 1, 8).valueOf());
  start = new Date(2022, 1, 8, 23, 59, 59, 1000);
  result = (0, _date.toSimpleISODateString)(start);
  t.equal(result, '2022-02-09', 'handles low');
  t.equal((0, _date.fromSimpleISODateString)(result).valueOf(), new Date(2022, 1, 9).valueOf());
  t.equal((0, _date.toSimpleISODateString)(1644393600000), '2022-02-09', 'handles ms value');
  t.end();
});
(0, _tape.default)('msToTimeAgo', t => {
  const cases = [[-120, '0s'], [5000, '5s'], [15000, '15s'], [999, '0s'], [1800, '0m', false], [60000, '1m', false], [60000 * 150, '2h 30m', false], [60000 * 179, '2h 59m', false], [60000 * 59, '59m', false], [60000 * 59 + 1000, '59m 1s']];

  for (const entry of cases) {
    t.equal((0, _date.msToTimeAgo)(entry[0], entry[2]), entry[1], "".concat(entry[0], " should be ").concat(entry[1]));
  }

  t.end();
});
(0, _tape.default)('formatBirthDate', t => {
  let pad = num => (num + '').padStart(2, '0');

  const generateForMonth = (monthNumber, name, days) => {
    const res = [];

    for (let i = 1; i <= days; i++) {
      res.push(["2018-".concat(pad(monthNumber + 1), "-").concat(pad(i)), "".concat(name, " ").concat(i, ", 2018")]);
    }

    return res;
  };

  const dateWith31 = new Date(2023, 9, 31);
  const expected = [['2018-02-12', 'February 12, 2018', dateWith31], // this caused an issue before bugfix
  ['2018-01-01', 'January 1, 2018'], ...generateForMonth(0, 'January', 31), ...generateForMonth(1, 'February', 28), ...generateForMonth(2, 'March', 31), ...generateForMonth(3, 'April', 30), ...generateForMonth(4, 'May', 31), ...generateForMonth(5, 'June', 30), ...generateForMonth(6, 'July', 31), ...generateForMonth(7, 'August', 31), ...generateForMonth(8, 'September', 30), ...generateForMonth(9, 'October', 31), ...generateForMonth(10, 'November', 30), ...generateForMonth(11, 'December', 31), // also check year by itself
  ['2018', '2018'], ['2018-02', 'February 2018']];

  for (const entry of expected) {
    t.equal((0, _date.formatBirthDate)(entry[0], entry[2]), entry[1], "".concat(entry[0], " should be ").concat(entry[1]));
  }

  t.end();
});
(0, _tape.default)('toTimeString', t => {
  const cases = [[0, 0, '00:00'], [0, 5, '00:05'], [1, 0, '01:00'], [12, 0, '12:00'], [13, 0, '13:00'], [23, 0, '23:00'], [24, 0, '00:00']];

  for (const entry of cases) {
    t.equal((0, _date.toTimeString)(new Date(2022, 1, 8, entry[0], entry[1]).valueOf()), entry[2], "".concat(entry[0], " should be ").concat(entry[2]));
  } // now with seconds


  const casesWithSeconds = [[0, 0, 0, '00:00:00'], [0, 5, 0, '00:05:00'], [1, 0, 0, '01:00:00'], [12, 0, 0, '12:00:00'], [13, 0, 0, '13:00:00'], [23, 0, 0, '23:00:00'], [24, 0, 0, '00:00:00'], [0, 0, 1, '00:00:01'], [0, 5, 1, '00:05:01'], [1, 0, 1, '01:00:01'], [12, 0, 59, '12:00:59'], [13, 0, 1, '13:00:01'], [23, 0, 1, '23:00:01'], [24, 0, 1, '00:00:01']];

  for (const entry of casesWithSeconds) {
    t.equal((0, _date.toTimeString)(new Date(2022, 1, 8, entry[0], entry[1], entry[2]).valueOf(), true), entry[3], "".concat(entry[0], " should be ").concat(entry[3]));
  }

  t.end();
});
(0, _tape.default)('toDateString', t => {
  const casesWithSeconds = [[0, 0, 0, '2/8/2022 00:00:00'], [0, 5, 0, '2/8/2022 00:05:00'], [1, 0, 0, '2/8/2022 01:00:00'], [12, 0, 0, '2/8/2022 12:00:00'], [13, 0, 0, '2/8/2022 13:00:00'], [23, 0, 0, '2/8/2022 23:00:00'], [0, 0, 1, '2/8/2022 00:00:01'], [0, 5, 1, '2/8/2022 00:05:01'], [1, 0, 1, '2/8/2022 01:00:01'], [12, 0, 59, '2/8/2022 12:00:59'], [13, 0, 1, '2/8/2022 13:00:01'], [23, 0, 1, '2/8/2022 23:00:01']];

  for (const entry of casesWithSeconds) {
    t.equal((0, _date.toDateString)(new Date(2022, 1, 8, entry[0], entry[1], entry[2]).valueOf(), true, true), entry[3], "".concat(entry[0], " ").concat(entry[1], " ").concat(entry[2], "  should be ").concat(entry[3]));
  }

  for (const entry of casesWithSeconds) {
    // remove last 3 character from entry[3]
    const expected = entry[3].slice(0, -3);
    t.equal((0, _date.toDateString)(new Date(2022, 1, 8, entry[0], entry[1], entry[2]).valueOf(), true // not including seconds this time
    ), expected, "".concat(entry[0], " ").concat(entry[1], " ").concat(entry[2], " should be if seconds are excluded ").concat(expected));
  }

  for (const entry of casesWithSeconds) {
    // remove last 9 character from entry[3]
    const expected = entry[3].slice(0, -9);
    t.equal((0, _date.toDateString)(new Date(2022, 1, 8, entry[0], entry[1], entry[2]).valueOf() // not including time or seconds this time
    ), expected, "".concat(entry[0], " ").concat(entry[1], " ").concat(entry[2], " should be if seconds are excluded ").concat(expected));
  }

  t.end();
});
(0, _tape.default)('formatDOB', t => {
  const cases = [[null, null], [undefined, null], [{}, null], ['2020-01-01', '1/1/2020'], ['blah', null], ['2020', '1/1/2020'], ['2020-08', '8/1/2020']];

  for (const entry of cases) {
    t.equal((0, _date.formatDOB)(entry[0]), entry[1], "".concat(entry[0], " should be ").concat(entry[1]));
  }

  t.end();
});
(0, _tape.default)('dobToAgeInfo', t => {
  // only doing high level input/output testing
  // components are all tested individually elsewhere.
  const cases = [[null, null], [undefined, null], [{}, null], ['2020-01-01', {
    dateString: '2020-01-01',
    formattedDOB: '1/1/2020'
  }], ['blah', null], ['2020', {
    dateString: '2020',
    formattedDOB: '1/1/2020'
  }], ['2020-08', {
    dateString: '2020-08',
    formattedDOB: '8/1/2020'
  }], ['dec 28, 47', {
    dateString: '1947-12-28',
    formattedDOB: '12/28/1947'
  }]];

  for (const entry of cases) {
    const info = (0, _date.dobToAgeInfo)(entry[0]);
    const expected = entry[1];

    if (expected) {
      t.equal(typeof info.age, 'number'); // we do this so it won't break in the future

      delete info.age;
    }

    t.deepEqual(info, expected, "".concat(entry[0], " should be ").concat(expected));
  }

  t.end();
});