"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.trimDrugName = exports.trimText = void 0;

/**
 * Trims the string to the given length, adding an ellipsis if necessary. The
 * ellipsis counts as a character so the returned string will be at most
 * `maxLen` characters.
 *
 * @param {string} name
 * @param {string} maxLen
 * @returns {string}
 */
const trimText = (str, maxLen) => {
  if (str.length > maxLen) {
    return str.slice(0, maxLen - 1) + '…';
  }

  return str;
};

exports.trimText = trimText;
const abbrevs = {
  hydrochloride: 'HCl',
  chloride: 'Cl'
};
/**
 * First applies accepted abbreviations for suffixes then trims the string.
 *
 * @param {string} name
 * @param {string} maxLen
 * @returns {string}
 */

const trimDrugName = (name, maxLen) => {
  if (name.length <= maxLen) return name;

  for (const full in abbrevs) {
    const abbr = abbrevs[full];

    if (name && name.toLowerCase().endsWith(full)) {
      name = name.slice(0, -full.length) + abbr;
    }
  }

  return trimText(name, maxLen);
};

exports.trimDrugName = trimDrugName;